==> OneHitWonder_4216_v0.038.zip: Interface/AddOns/OneHitWonder/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_ONEHITWONDERHEADER							= "One Hit Wonder";
BINDING_NAME_ONEHITWONDER_TOGGLE_REMOVEDEFENSE				= "Toggle decrease armor";
BINDING_NAME_ONEHITWONDER_TOGGLE_BOSSMODE					= "Toggle boss mode";
BINDING_NAME_ONEHITWONDER_TOGGLE_INNERFIRE					= "(Priest) Toggle Inner Fire";
BINDING_NAME_ONEHITWONDER_BUFF_BUTTON						= "Its Buff Time!";
BINDING_NAME_ONEHITWONDER_CLEAN_BUTTON						= "Its Cleaning Time!";

ONEHITWONDER_TOGGLE_ENABLED_CHAT							= "enabled";
ONEHITWONDER_TOGGLE_DISABLED_CHAT							= "disabled";

ONEHITWONDER_TOGGLE_INNERFIRE_CHAT							= "Toggle Inner Fire %s";

BINDING_NAME_ONEHITWONDER									= "OneHitWonder!";

BINDING_NAME_ONEHITWONDER_COUNTERMEASURES					= "Execute any pending reactive action";

ONEHITWONDER_CONFIG_HEADER									= "OneHitWonder";
ONEHITWONDER_CONFIG_HEADER_INFO								= "Contains settings for the One Hit Wonder,\nan AddOn which allows you to mash one button\nwithout ever actually using any of your abilities.\n\nSupremely automated.\nMade for farming.\nNo bears attached.\n\nA Sarf Production.";

ONEHITWONDER_ENABLED										= "Enable OneHitWonder";
ONEHITWONDER_ENABLED_INFO									= "Enables OneHitWonder, allowing FULL* automation of combat.* almost... all you need is a human being operating the client";

ONEHITWONDER_OVERRIDE_BINDINGS								= "Intercept bindings";
ONEHITWONDER_OVERRIDE_BINDINGS_INFO							= "Allows OneHitWonder to intercept normal keypresses, other than the OHW specific bindings. May require restart of WoW.";

ONEHITWONDER_SHOW_INFO_MESSAGES								= "Show informational messages";
ONEHITWONDER_SHOW_INFO_MESSAGES_INFO						= "Allows OHW to show user messages what it is doing.";

ONEHITWONDER_SHOW_REACTIVE_TEXT								= "Show reactive text";
ONEHITWONDER_SHOW_REACTIVE_TEXT_INFO						= "If enabled, OHW will show a big text whenever it thinks you should do something.";

ONEHITWONDER_SHOW_QUEUE										= "Show action queue";
ONEHITWONDER_SHOW_QUEUE_INFO								= "Will show the action queue window.";

ONEHITWONDER_KEEP_UP_BUFFS									= "Keeps up self-buffs";
ONEHITWONDER_KEEP_UP_BUFFS_INFO								= "Keeps up buffs on self";

ONEHITWONDER_KEEP_UP_BUFFS_PARTY							= "Keeps up buffs on party";
ONEHITWONDER_KEEP_UP_BUFFS_PARTY_INFO						= "Keeps up buffs on party members";

ONEHITWONDER_NO_BUFF_WHILE_FISHING							= "Do not buff while fishing";
ONEHITWONDER_NO_BUFF_WHILE_FISHING_INFO						= "Will make OHW refrain from buffing while you have a Fishing Pole (or other Fishing item) equipped.";

ONEHITWONDER_REMOVE_DEBUFFS									= "Remove debuffs from self and party";
ONEHITWONDER_REMOVE_DEBUFFS_INFO							= "Will attempt to remove debuffs from self and party (and pet!)";

ONEHITWONDER_CHAT_ENABLED									= "One Hit Wonder enabled.";
ONEHITWONDER_CHAT_DISABLED									= "One Hit Wonder disabled.";

ONEHITWONDER_CHAT_COMMAND_ENABLE_INFO						= "Enables/disables One Hit Wonder.";

ONEHITWONDER_CHAT_REMOVEDEFENSE_ENABLED						= "OHW: Heavy armor mob handling enabled.";
ONEHITWONDER_CHAT_REMOVEDEFENSE_DISABLED					= "OHW: Heavy armor mob handling disabled.";

ONEHITWONDER_CHAT_BOSSMOB_ENABLED							= "OHW: Boss mob (5 CP actions) handling enabled.";
ONEHITWONDER_CHAT_BOSSMOB_DISABLED							= "OHW: Boss mob (5 CP actions) handling disabled.";

ONEHITWONDER_IMPERATIVE_ABILITY_MESSAGE						= "Use %s!";




-- Player frame


-- Pickpocket stuff

ONEHITWONDER_LEVEL_PATTERN									= "Level %d";


ONEHITWONDER_ACTION_QUEUE_UPDATED 							= "";

ONEHITWONDER_ATTACK_ACTION_NAME								= "Attack";


-- Map names

ONEHITWONDER_CONTINENT_AZEROTH_NAME							= "Azeroth";
ONEHITWONDER_CONTINENT_KALIMDOR_NAME						= "Kalimdor";

if ( GetLocale() == "frFR" ) then
elseif ( GetLocale() == "deDE" ) then
end

==> OneHitWonder_4216_v0.041.zip: Interface/AddOns/OneHitWonder/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_ONEHITWONDERHEADER							= "One Hit Wonder";
BINDING_NAME_ONEHITWONDER_TOGGLE_REMOVEDEFENSE				= "Toggle decrease armor";
BINDING_NAME_ONEHITWONDER_TOGGLE_DOT					= "Toggle Damage Over Time";
BINDING_NAKE_ONEHITWONDER_CYCLE_WEAPONBUFF 					= "Cycle Weapon Buff";
BINDING_NAME_ONEHITWONDER_TOGGLE_BOSSMODE					= "Toggle boss mode";
BINDING_NAME_ONEHITWONDER_TOGGLE_INNERFIRE					= "(Priest) Toggle Inner Fire";
BINDING_NAME_ONEHITWONDER_BUFF_BUTTON						= "Its Buff Time!";
BINDING_NAME_ONEHITWONDER_CLEAN_BUTTON						= "Its Cleaning Time!";

ONEHITWONDER_UNIT_FLEE_STATE								= "f";

ONEHITWONDER_TOGGLE_ENABLED_CHAT							= "enabled";
ONEHITWONDER_TOGGLE_DISABLED_CHAT							= "disabled";

ONEHITWONDER_TOGGLE_INNERFIRE_CHAT							= "Toggle Inner Fire %s";

BINDING_NAME_ONEHITWONDER									= "OneHitWonder!";

BINDING_NAME_ONEHITWONDER_COUNTERMEASURES					= "Execute any pending reactive action";

ONEHITWONDER_CONFIG_HEADER									= "OneHitWonder";
ONEHITWONDER_CONFIG_HEADER_INFO								= "Contains settings for the One Hit Wonder,\nan AddOn which allows you to mash one button\nwithout ever actually using any of your abilities.\n\nSupremely automated.\nMade for farming.\nNo bears attached.\n\nA Sarf Production.";

ONEHITWONDER_ENABLED										= "Enable OneHitWonder";
ONEHITWONDER_ENABLED_INFO									= "Enables OneHitWonder, allowing FULL* automation of combat.* almost... all you need is a human being operating the client";

ONEHITWONDER_OVERRIDE_BINDINGS								= "Intercept bindings";
ONEHITWONDER_OVERRIDE_BINDINGS_INFO							= "Allows OneHitWonder to intercept normal keypresses, other than the OHW specific bindings. May require restart of WoW.";

ONEHITWONDER_SHOW_INFO_MESSAGES								= "Show informational messages";
ONEHITWONDER_SHOW_INFO_MESSAGES_INFO						= "Allows OHW to show user messages what it is doing.";

ONEHITWONDER_SHOW_REACTIVE_TEXT								= "Show reactive text";
ONEHITWONDER_SHOW_REACTIVE_TEXT_INFO						= "If enabled, OHW will show a big text whenever it thinks you should do something.";

ONEHITWONDER_SHOW_QUEUE										= "Show action queue";
ONEHITWONDER_SHOW_QUEUE_INFO								= "Will show the action queue window.";

ONEHITWONDER_KEEP_UP_BUFFS									= "Keeps up self-buffs";
ONEHITWONDER_KEEP_UP_BUFFS_INFO								= "Keeps up buffs on self";

ONEHITWONDER_KEEP_UP_BUFFS_PARTY							= "Keeps up buffs on party";
ONEHITWONDER_KEEP_UP_BUFFS_PARTY_INFO						= "Keeps up buffs on party members";

ONEHITWONDER_NO_BUFF_WHILE_FISHING							= "Do not buff while fishing";
ONEHITWONDER_NO_BUFF_WHILE_FISHING_INFO						= "Will make OHW refrain from buffing while you have a Fishing Pole (or other Fishing item) equipped.";

ONEHITWONDER_REMOVE_DEBUFFS									= "Remove debuffs from self and party";
ONEHITWONDER_REMOVE_DEBUFFS_INFO							= "Will attempt to remove debuffs from self and party (and pet!)";

ONEHITWONDER_CHAT_ENABLED									= "One Hit Wonder enabled.";
ONEHITWONDER_CHAT_DISABLED									= "One Hit Wonder disabled.";

ONEHITWONDER_CHAT_COMMAND_ENABLE_INFO						= "Enables/disables One Hit Wonder.";

ONEHITWONDER_CHAT_REMOVEDEFENSE_ENABLED						= "OHW: Heavy armor mob handling enabled.";
ONEHITWONDER_CHAT_REMOVEDEFENSE_DISABLED					= "OHW: Heavy armor mob handling disabled.";

ONEHITWONDER_CHAT_DOT_ENABLED								= "OHW: Damage over Time-infliction enabled.";
ONEHITWONDER_CHAT_DOT_DISABLED								= "OHW: Damage over Time-infliction disabled.";

ONEHITWONDER_CHAT_BOSSMOB_ENABLED							= "OHW: Boss mob (5 CP actions) handling enabled.";
ONEHITWONDER_CHAT_BOSSMOB_DISABLED							= "OHW: Boss mob (5 CP actions) handling disabled.";

ONEHITWONDER_IMPERATIVE_ABILITY_MESSAGE						= "Use %s!";




-- Player frame


-- Pickpocket stuff

ONEHITWONDER_LEVEL_PATTERN									= "Level %d";


ONEHITWONDER_ACTION_QUEUE_UPDATED 							= "";

ONEHITWONDER_ATTACK_ACTION_NAME								= "Attack";


-- Map names

ONEHITWONDER_CONTINENT_AZEROTH_NAME							= "Azeroth";
ONEHITWONDER_CONTINENT_KALIMDOR_NAME						= "Kalimdor";

if ( GetLocale() == "frFR" ) then
elseif ( GetLocale() == "deDE" ) then
end
